// -*- c++ -*-
//
//   R : A Computer Language for Statistical Data Analysis
//   Copyright (C) 2000  the R Development Core Team

//   This program is free software; you can redistribute it and/or modify
//   it under the terms of the GNU General Public License as published by
//   the Free Software Foundation; either version 2 of the License, or
//   (at your option) any later version.

//   This program is distributed in the hope that it will be useful,
//   but WITHOUT ANY WARRANTY; without even the implied warranty of
//   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//   GNU General Public License for more details.

//   You should have received a copy of the GNU General Public License
//   along with this program; if not, write to the Free Software
//   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

#ifndef _SVD_H_
#define _SVD_H_

#include "lafnames.h"
#include LA_GEN_MAT_DOUBLE_H
#include LA_VECTOR_DOUBLE_H
#include "orthonormal.h"

class SVD {
 public:
    SVD(LaGenMatDouble& a, int nu = 0, int nvt = 0);
    
    inline LaVectorDouble& getS() {return s;}
    inline LaColOrthonormalMatDouble& getU() {return u;}
    inline LaRowOrthonormalMatDouble& getVT() {return vt;}
    
 protected:
    LaVectorDouble s;
    LaColOrthonormalMatDouble u;
    LaRowOrthonormalMatDouble vt;
};

#endif
